@@ -4,18 +4,17 @@
 // Defines determined during configuration of m4ri.
 #define __M4RI_HAVE_MM_MALLOC		1
 #define __M4RI_HAVE_POSIX_MEMALIGN	1
-#define __M4RI_HAVE_SSE2		0
+#define __M4RI_HAVE_SSE2		(defined(__SSE2__) && __SSE2__)
 #define __M4RI_HAVE_OPENMP		0
-#define __M4RI_CPU_L1_CACHE		65536
-#define __M4RI_CPU_L2_CACHE		4194304
-#define __M4RI_CPU_L3_CACHE		4194304
+#define __M4RI_CPU_L1_CACHE		131072
+#define __M4RI_CPU_L2_CACHE		12582912
+#define __M4RI_CPU_L3_CACHE		12582912
 #define __M4RI_DEBUG_DUMP		(0 || 0)
 #define __M4RI_DEBUG_MZD		0
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "/usr/bin/clang"
-#define __M4RI_CFLAGS                   "  -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk -arch arm64"
-#define __M4RI_SIMD_CFLAGS              ""
+#define __M4RI_CFLAGS                   " -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk -arch arm64"
 #define __M4RI_OPENMP_CFLAGS            ""
 
 // Helper macros.
